# Material Library

The goal of this stand-alone submodule is to provide a library of materials that can be used in the simulation.
The materials are defined in terms of their optical and electronic properties and can be used to define the medium of the simulation in flexible ways.
This library provides a set of useful scripts to extract the medium data from the raw material files and use them in the simulation.

